<?php
/**
 * @copyright © 2009 Intrahealth International, Inc.
 * This File is part of I2CE
 *
 * I2CE is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
*  I2CE_Swiss_CustomReports_ReportView_Field
* @package I2CE
* @subpackage Core
* @author Carl Leitner <litlfred@ibiblio.org>
* @version 2.1
* @access public
*/


class I2CE_Swiss_CustomReports_ReportView_Field extends I2CE_Swiss_CustomReports_ReportView_Base{

    public function getHeader() {
        $swissReportView = $this->getBaseReportView();
        if (!$swissReportView instanceof I2CE_Swiss_CustomReports_ReportView) {
            return $this->humanText($this->name);
        }
        $swissReport = $swissReportView->getSwissReport($swissReportView->getReport());
        if (!$swissReport instanceof I2CE_Swiss_CustomReports_Report) {
            return $this->humanText($this->name);
        }
        list($reportform,$field) = array_pad(explode('+',$this->name),2,'');
        if ($reportform) {
            $swissField = $swissReport->getSwissField($reportform,$field);
            if ($swissField instanceof I2CE_Swiss_CustomReports_Report_ReportingForm_Field) {
                return $swissField->getHeader();
            }
        } else {
            //its a reporting function
            $swissFunc = $swissReport->getSwissFunction($field);
            if ($swissFunc instanceof I2CE_Swiss_CustomReports_Report_ReportingFunction) {                
                return $swissFunc->getHeader();
            }
        }
        return $this->humanText($this->name);
    }

    protected $form;
    protected function getForm() {
        if ($this->form === null) {
            $reportView = $this->getBaseReportView();
            if (!$reportView instanceof I2CE_Swiss_CustomReports_ReportView) {
                return null;
            }
            if ($reportView->getReport() === false) {
                return null;
            }
            $report = $this->getSwissReport($reportView->getReport());
            if (!$report instanceof I2CE_Swiss_CustomReports_Report) {
                return null;
            }
            $relationship = $report->getSwissRelationship();
            if (!$relationship instanceof I2CE_Swiss_FormRelationship) {
                return null;
            }
            list($reportform,$field) = explode('+',$this->name);
            if ($reportform == 'primary_form') {
                $this->form = $relationship->getForm();
            } else {
                $swissForm = $relationship->getSwissForm($reportform);
                if ($swissForm instanceof I2CE_Swiss_FormRelationship) {
                    $this->form = $swissForm->getForm();
                }
            }
        }
        return $this->form;
    }
    public function isNumeric() {
        list($reportform,$field) = array_pad(explode('+',$this->name),2,'');
        if (!$field) {
            return false;
        }
        if ($reportform) {
            $form = $this->getForm();
            if (!$form) {
                return false;
            }
            $factory = I2CE_FormFactory::instance();
            $formObj = $factory->createForm($form);
            if (!$formObj instanceof I2CE_Form) {
                return false;
            }
            return  $formObj->isNumeric($field);         
        } else {
            //it is a reporting function
            $reportView = $this->getBaseReportView();
            if (!$reportView instanceof I2CE_Swiss_CustomReports_ReportView) {
                return false;
            }
            if ($reportView->getReport() === false) {
                return false;
            }
            $report = $this->getSwissReport($reportView->getReport());
            if (!$report instanceof I2CE_Swiss_CustomReports_Report) {
                return false;
            }
            $relationship = $report->getSwissRelationship();
            if (!$relationship instanceof I2CE_Swiss_FormRelationship) {
                return false;
            }
            $funcs = $relationship->getChild('functions');
            if (!$funcs instanceof I2CE_Swiss_FormRelationship_Functions) {
                return false;
            }
            $func = $funcs->getChild($field);
            if (!$func instanceof I2CE_Swiss_SQLFunction) {
                return false;
            }
            return $func->isNumeric();
        }
    }

    protected $reportField = false;

    protected function getReportField() {
        if ($this->reportField) {
            return $this->reportField;
        }
        $reportView = $this->getBaseReportView();
        if (!$reportView instanceof I2CE_Swiss_CustomReports_ReportView) {
            return false;
        }
        if ($reportView->getReport() === false) {
            return false;
        }
        $report = $this->getSwissReport($reportView->getReport());
        if (!$report instanceof I2CE_Swiss_CustomReports_Report) {
            return false;
        }        
        list($reportform,$field) = array_pad(explode('+',$this->name),2,'');
        if (!$field) {
            return false;
        }
        if (strlen($reportform)>0) {
            $swissForms = $report->getChild('reporting_forms');
            if (!$swissForms instanceof I2CE_Swiss) {
                return false;
            }
            $swissForm  = $swissForms->getChild($reportform);
            if (!$swissForm instanceof I2CE_Swiss) {
                return false;
            }
            $swissFields = $swissForm->getChild('fields');
            if (!$swissFields instanceof I2CE_Swiss) {
                return false;
            }
            $field = $swissFields->getChild($field);
            if (!$field instanceof I2CE_Swiss_CustomReports_Report_ReportingForm_Field) {
                return false;
            }
            $this->reportField = $field;            
        } else {
            $swissFunctions = $report->getChild('reporting_functions');
            if (!$swissFunctions instanceof I2CE_Swiss) {
                return false;
            }
            $field  = $swissFunctions->getChild($field);            
            if (!$field instanceof I2CE_Swiss_CustomReports_Report_ReportingFunction) {
                return false;
            }
            $this->reportField = $field;            
        }
        return $this->reportField;
    }
        

    public function isEnabledInReport() {
        $field = $this->getReportField();
        if (!$field) {
            return false;
        }        
        return ($field->isInRelationship() && $field->isEnabled());
    }

    public function processValues($values) {
        if (array_key_exists('enabled_hide',$values)) {
            if (array_key_exists('enabled',$values) && $values['enabled']) {
                $this->setEnabled(true);
            } else {
                $this->setEnabled(false);
            }
        }
        if (array_key_exists('aggregate',$values)) {
            $this->setAggregation($values['aggregate']);
        }
        return true;
    }
    
    public function isEnabled() {
        return ($this->hasField('enabled') && $this->getField('enabled') == 1);
    }

    public function setEnabled($enab) {
        if ($enab) {
            $this->setField('enabled','1');
        } else {
            $this->setField('enabled','0');
        }
    }
    
    public function setAggregation($agg) {
        $this->setField('aggregate',$agg);
    }

    public function getAggregation() {
        if (!$this->hasField('aggregate')) {
            return 'none';
        }
        return $this->getField('aggregate');
    }
    

        
    public function displayValues($contentNode, $transient_options, $action) {
        if ($this->isNumeric()) {
            $template ="customReports_reportView_field_numeric.html";
        } else {
            $template ="customReports_reportView_field.html";
        }
        $mainNode = $this->template->appendFileByNode($template,'span',$contentNode);
        if (!$mainNode instanceof DOMNode) {
            I2CE::raiseError("Could not load report views template");
            return false;
        }   
        $this->template->setDisplayDataImmediate('name', $this->name, $mainNode);
        $this->template->setDisplayDataImmediate('displayName', $this->getHeader(), $mainNode);
        $this->template->setDisplayDataImmediate('enabled',$this->isEnabled(), $mainNode);
        $this->template->selectOptionsImmediate('aggregate',$this->getAggregation(),$mainNode);
        $this->renameInputs(array('enabled','enabled_hide','aggregate'), $mainNode);
        return true;
    }




    

}
# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
