<?php
/*
 * © Copyright 2007, 2008 IntraHealth International, Inc.
 * 
 * This File is part of iHRIS
 * 
 * iHRIS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * Translate Templates
 *
 * @package I2CE
 * @subpackage Core
 * @author Carl Leitner <litlfred@ibiblio.org>
 * @copyright Copyright &copy; 2008, 2008 IntraHealth International, Inc. 
 * @version 1.0
 */

error_reporting(E_ALL);
set_include_path(get_include_path() . PATH_SEPARATOR . dirname(__FILE__) . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . 'lib');

$blue = "\033[34m";
$black = "\033[0m";
$red = "\033[31m";
$green = "\033[32m";


if (!isset($booleans) || !is_array($booleans)) {
    $booleans[] = array();
}
if (!isset($usage) || !is_array($usage)) {
    $usage = array();
}


@require_once ("Console/Getopt.php");  
if (!class_exists('Console_Getopt')) {
    usage('Please install the PEAR Console_Getopt package');
}


function usage($msg = '',$die = true) {
    global $usage;
     if ($msg) {
        echo $msg . "\n";
    }
    $debug = debug_backtrace();
    $file = basename($debug[count($debug)-1]['file']);
    echo "Usage: " . $file . "\n";
    echo implode("",$usage);
    if ($die) {
        die();
    }
}



$cg = new Console_Getopt();  
$t_args = $cg->readPHPArgv(); 
$modules =false;
array_shift($t_args);
$args = array();


$arg_files  = array();
while (count($t_args) > 0) {
    $arg = array_shift($t_args);
    list($key,$val) = array_pad(explode('=',$arg),2,'');
    if (strlen($key)  == 0) {
        usage( "Bad argument $key");
    }
    if (substr($key,0,2) == '--') {
        if (strlen($key) < 3) {
            usage( "Bad argument $key");
        }
        $key = substr($key,2);        
        if ($key  == 'help') {
            usage(); 
        }
    } else if ($key[0] == '-') {
        if (strlen($key) < 2) {
            usage( "Bad argument $key");
        }
        $key = substr($key,1);        
        if ($key  == 'h') {
            usage(); 
        }
    } else {
        $arg_files[] = $arg;
        continue;
    }
    if (strlen($val) == 0) {
        usage("Bad value [$val] for argument $key");
    }
    switch($key) {
    case 'search_dirs':
        $search_dirs = preg_split('/,/',$val,-1,PREG_SPLIT_NO_EMPTY);
        if (count($search_dirs) == 0) {
            usage("No valid search directories specified");
        }
        break;
    case 'modules':
        $modules = preg_split('/,/',$val,-1,PREG_SPLIT_NO_EMPTY);
        if (count($modules) == 0) {
            usage("No valid modules specified");
        }
        break;
    default:
        if (array_key_exists($key,$booleans)) {
            if ($val == '0' || (is_string($val) && strlen($val) > 0 && strtoupper(substr($val,0,1)) == 'F')) {
                $booleans[$key] = false;
            } else  if ($val == '1' || (is_string($val) && strlen($val) > 0 && strtoupper(substr($val,0,1)) == 'T')) {
                $booleans[$key] = true;
            }
        } else {
            $args[$key]=$val;
        }
        break;
    }
}




function prompt ($message,&$universal, $show=null) {
    global $red,$black;
    if ($universal === true) {
        return true;
    }
    if ($universal === false) {
        return false;
    }
    $message = trim($message);
    if ($show) {
        echo "$message\n({$red}Y{$black}es/{$red}N{$black}o/{$red}A{$black}lways/ne{$red}V{$black}er/{$red}S{$black}how): ";
    } else {
        echo "$message\n({$red}Y{$black}es/{$red}N{$black}o/{$red}A{$black}lways/ne{$red}V{$black}er): ";
    }
    $success =false;
    while (true) {
        $c = strtolower(fread(STDIN,1));
        if ($c=== false) {
            echo ("Bad input");
            die();
        }
        switch ($c) {
        case 'y':
            return true;
        case 'n':
            return false;
        case 'a':
            $universal = true;
            return true;
        case 'v':
            $universal = false;
            return false;
        case 's':
            if ($show) {
                echo "\n" . $show . "\n";
                echo "$message\n({$red}Y{$black}es/{$red}N{$black}o/{$red}A{$black}lways/ne{$red}V{$black}er): ";
                $show =false;
            }
            break;            
        default:
            break;
        }
    }
    echo "\n";
}


function simple_prompt ($message) {
    global $red,$black;
    $message = trim($message);
    echo "$message\n({$red}Y{$black}es/{$red}N{$black}o): ";
    $success =false;
    while (true) {
        $c = strtolower(fread(STDIN,1));
        if ($c=== false) {
            echo ("Bad input");
            die();
        }
        switch ($c) {
        case 'y':
            return true;
        case 'n':
            return false;
        default:
            break;
        }
    }
    echo "\n";
}





function ask ($message, $length = 2000) {
    $message = trim($message);
    echo "$message: ";
    $success =false;
    return fread(STDIN,$length);
}



function getPassword($stars = true) {
    //stolen from http://www.dasprids.de/blog/2008/08/22/getting-a-password-hidden-from-stdin-with-php-cli
    // Get current style
    $oldStyle = shell_exec('stty -g');
    
    if ($stars === false) {
        shell_exec('stty -echo');
        $password = rtrim(fgets(STDIN), "\n");
    } else {
        shell_exec('stty -icanon -echo min 1 time 0');
        
        $password = '';
        while (true) {
            $char = fgetc(STDIN);
            
            if ($char === "\n") {
                break;
            } else if (ord($char) === 127) {
                if (strlen($password) > 0) {
                    fwrite(STDOUT, "\x08 \x08");
                    $password = substr($password, 0, -1);
                }
            } else {
                fwrite(STDOUT, "*");
                $password .= $char;
            }
        }
    }
    
    // Reset old style
    shell_exec('stty ' . $oldStyle);
    
    // Return the password
    return $password;
}




